<?php

App::uses('EvTemplatesAppModel', 'EvTemplates.Model');

abstract class AttachmentBlock extends EvTemplatesAppModel
{
    public $belongsTo = array(
        'Template' => array(
            'className' => 'EvTemplates.Template'
        )
    );

    /**
     * redefine the beforeSave to add checks for the name. Default to main if none set
     * Also serialize the blockFields
     */
    public function beforeSave($options = array())
    {
        $return = parent::beforeSave($options);

        if (! empty($this->data[$this->alias])) {

            // default any blocks with no name to "Main"
            if (empty($this->data[$this->alias]['name'])) {

                $this->data[$this->alias]['name'] = 'main';
            }

            // camelCase any names so we can get MainImage / ListingImage / GalleryThumbImage
            $this->data[$this->alias]['name'] = InflectorExt::camelize($this->data[$this->alias]['name']);

            // Serialise any select fields
            $this->data[$this->alias]['blockFields'] = json_encode($this->data[$this->alias]['blockFields']);
        }

        return $return;
    }


    /**
     * redefine the afterFind to unserialize any fields
     *
     */
    public function afterFind($results, $primary = false)
    {
        $results = parent::afterFind($results, $primary);

        if (! empty($results)) {

            foreach ($results as $key => $item) {

                if (! empty($item[$this->alias]['blockFields'])) {

                   $results[$key][$this->alias]['blockFields'] = json_decode($item[$this->alias]['blockFields'], true);
                }
            }
        }

        return $results;
    }


    /**
     * redefine the after delete to delete any actual images / documents that may exist
     *
     */
    public function afterDelete()
    {
        parent::afterDelete();

        $class = str_replace('Block', '', get_class($this));

        $Model = EvClassRegistry::init('EvCore.' . $class);

        // TODO: DELETE ACTUAL IMAGES / DOCUMENTS
    }

}
